@@ -17,6 +17,7 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
 
+import os
 import logging
 import shutil
 from subprocess import Popen, PIPE, call, TimeoutExpired
@@ -50,6 +51,10 @@ class ScrcpyNotFoundError(FileNotFoundError):
     pass
 
 
+class ScrcpyServerNotFoundError(FileNotFoundError):
+    pass
+
+
 class ScrcpyBridge:
     def __init__(self, path=None):
         if path is not None:
@@ -62,6 +67,11 @@ class ScrcpyBridge:
             raise ScrcpyNotFoundError("Could not find `scrcpy` on PATH. Make "
                                       "sure scrcpy is installed and "
                                       "accessible from the terminal.")
+        if os.getenv('SCRCPY_LDD'):
+            if os.getenv('LD_LIBRARY_PATH'):
+                os.environ['LD_LIBRARY_PATH'] += os.getenv('SCRCPY_LDD')
+            else:
+                os.environ['LD_LIBRARY_PATH'] = os.getenv('SCRCPY_LDD')
 
     def start(self, args, stdout=PIPE, stderr=PIPE):
         proc = Popen(
